==> jc-1.4.0.tar.gz: javax/swing/text/StringContent__24InsertUndo.h <==
// class javax.swing.text.StringContent$InsertUndo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 25d5483218f9512c javax_swing_text_StringContent__24InsertUndo
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_text_StringContent__24InsertUndo_H_
#define _JC_javax_swing_text_StringContent__24InsertUndo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_StringContent$object;

// Typedefs
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_refs	_jc_javax_swing_text_StringContent__24InsertUndo$sub_refs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs	_jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$refs	_jc_javax_swing_text_StringContent__24InsertUndo$refs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$nonrefs	_jc_javax_swing_text_StringContent__24InsertUndo$nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$object	_jc_javax_swing_text_StringContent__24InsertUndo$object;

typedef const struct _jc_javax_swing_text_StringContent__24InsertUndo$vmethods	_jc_javax_swing_text_StringContent__24InsertUndo$vmethods;
typedef const struct _jc_javax_swing_text_StringContent__24InsertUndo$vtable	_jc_javax_swing_text_StringContent__24InsertUndo$vtable;
typedef const struct _jc_javax_swing_text_StringContent__24InsertUndo$vtype	_jc_javax_swing_text_StringContent__24InsertUndo$vtype;

// Constructors
extern void _jc_javax_swing_text_StringContent__24InsertUndo$method$_init$bd085d9f543fbec7(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *, struct _jc_javax_swing_text_StringContent$object *, jint, jint);

// Virtual methods
extern void _jc_javax_swing_text_StringContent__24InsertUndo$method$redo$25b0fd1adab70c30(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *);
extern void _jc_javax_swing_text_StringContent__24InsertUndo$method$undo$2a1fa1bb5289512f(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StringContent__24InsertUndo$method_info$redo$25b0fd1adab70c30;
extern _jc_method _jc_javax_swing_text_StringContent__24InsertUndo$method_info$undo$2a1fa1bb5289512f;

// Virtual methods structure
struct _jc_javax_swing_text_StringContent__24InsertUndo$vmethods {
	void	(*redo$25b0fd1adab70c30)(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *);
	void	(*undo$2a1fa1bb5289512f)(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *);
};

// Vtable
struct _jc_javax_swing_text_StringContent__24InsertUndo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_text_StringContent__24InsertUndo$vmethods	javax_swing_text_StringContent__24InsertUndo;
};

// Vtype
struct _jc_javax_swing_text_StringContent__24InsertUndo$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StringContent__24InsertUndo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_refs {
	struct _jc_java_lang_String$object	*redoContent;
	struct _jc_javax_swing_text_StringContent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24InsertUndo$refs {
    _jc_javax_swing_text_StringContent__24InsertUndo$sub_refs	javax_swing_text_StringContent__24InsertUndo;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs {
	jint	start;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24InsertUndo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs	javax_swing_text_StringContent__24InsertUndo;
};

// Object instance structure
struct _jc_javax_swing_text_StringContent__24InsertUndo$object {
	_jc_javax_swing_text_StringContent__24InsertUndo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StringContent__24InsertUndo$vtype	*vtype;
	_jc_javax_swing_text_StringContent__24InsertUndo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StringContent__24InsertUndo$vtype _jc_javax_swing_text_StringContent__24InsertUndo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StringContent__24InsertUndo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StringContent__24InsertUndo$class_object;

#endif	/* _JC_javax_swing_text_StringContent__24InsertUndo_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StringContent__24InsertUndo.h <==
// class javax.swing.text.StringContent$InsertUndo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4df44da8a572d797 javax_swing_text_StringContent__24InsertUndo
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_text_StringContent__24InsertUndo_H_
#define _JC_javax_swing_text_StringContent__24InsertUndo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_StringContent$object;

// Typedefs
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_refs	_jc_javax_swing_text_StringContent__24InsertUndo$sub_refs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs	_jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$refs	_jc_javax_swing_text_StringContent__24InsertUndo$refs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$nonrefs	_jc_javax_swing_text_StringContent__24InsertUndo$nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24InsertUndo$object	_jc_javax_swing_text_StringContent__24InsertUndo$object;

typedef const struct _jc_javax_swing_text_StringContent__24InsertUndo$vmethods	_jc_javax_swing_text_StringContent__24InsertUndo$vmethods;
typedef const struct _jc_javax_swing_text_StringContent__24InsertUndo$vtable	_jc_javax_swing_text_StringContent__24InsertUndo$vtable;
typedef const struct _jc_javax_swing_text_StringContent__24InsertUndo$vtype	_jc_javax_swing_text_StringContent__24InsertUndo$vtype;

// Constructors
extern void _jc_javax_swing_text_StringContent__24InsertUndo$method$_init$bd085d9f543fbec7(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *, struct _jc_javax_swing_text_StringContent$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_StringContent__24InsertUndo$method$redo$25b0fd1adab70c30(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StringContent__24InsertUndo$method$undo$2a1fa1bb5289512f(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StringContent__24InsertUndo$method_info$redo$25b0fd1adab70c30;
extern _jc_method _jc_javax_swing_text_StringContent__24InsertUndo$method_info$undo$2a1fa1bb5289512f;

// Virtual methods structure
struct _jc_javax_swing_text_StringContent__24InsertUndo$vmethods {
	void	(*redo$25b0fd1adab70c30)(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *) _JC_JCNI_ATTR;
	void	(*undo$2a1fa1bb5289512f)(_jc_env *, struct _jc_javax_swing_text_StringContent__24InsertUndo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StringContent__24InsertUndo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_text_StringContent__24InsertUndo$vmethods	javax_swing_text_StringContent__24InsertUndo;
};

// Vtype
struct _jc_javax_swing_text_StringContent__24InsertUndo$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StringContent__24InsertUndo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_refs {
	struct _jc_java_lang_String$object	*redoContent;
	struct _jc_javax_swing_text_StringContent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24InsertUndo$refs {
    _jc_javax_swing_text_StringContent__24InsertUndo$sub_refs	javax_swing_text_StringContent__24InsertUndo;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs {
	jint	start;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24InsertUndo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_text_StringContent__24InsertUndo$sub_nonrefs	javax_swing_text_StringContent__24InsertUndo;
};

// Object instance structure
struct _jc_javax_swing_text_StringContent__24InsertUndo$object {
	_jc_javax_swing_text_StringContent__24InsertUndo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StringContent__24InsertUndo$vtype	*vtype;
	_jc_javax_swing_text_StringContent__24InsertUndo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StringContent__24InsertUndo$vtype _jc_javax_swing_text_StringContent__24InsertUndo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StringContent__24InsertUndo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StringContent__24InsertUndo$class_object;

#endif	/* _JC_javax_swing_text_StringContent__24InsertUndo_H_ */
